==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/es-SV.pl <==
{
  am_pm_abbreviated => [
    "a. m.",
    "p. m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E d",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMM => "MMMM 'de' y G",
    GyMMMMEd => "E, d 'de' MMMM 'de' y G",
    GyMMMMd => "d 'de' MMMM 'de' y G",
    GyMMMd => "d 'de' MMM 'de' y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "H:mm:ss v",
    Hmsvvvv => "H:mm:ss (vvvv)",
    Hmv => "H:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d 'de' MMMM",
    "MMMMW-count-one" => "'semana' W 'de' MMM",
    "MMMMW-count-other" => "'semana' W 'de' MMM",
    MMMMd => "d 'de' MMMM",
    MMMd => "d MMM",
    MMMdd => "dd-MMM",
    MMd => "d/M",
    MMdd => "d/M",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmsvvvv => "h:mm:ss a (vvvv)",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMM => "M/y",
    yMMM => "MMMM 'de' y",
    yMMMEd => "E, d 'de' MMM 'de' y",
    yMMMM => "MMMM 'de' y",
    yMMMMEd => "EEE, d 'de' MMMM 'de' y",
    yMMMMd => "d 'de' MMMM 'de' y",
    yMMMd => "d 'de' MMMM 'de' y",
    yMd => "d/M/y",
    yQQQ => "QQQ 'de' y",
    yQQQQ => "QQQQ 'de' y",
    "yw-count-one" => "'semana' w 'de' Y",
    "yw-count-other" => "'semana' w 'de' Y",
  },
  code => "es-SV",
  date_format_full => "EEEE, d 'de' MMMM 'de' y",
  date_format_long => "d 'de' MMMM 'de' y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lun.",
    "mar.",
    "mi\N{U+00e9}.",
    "jue.",
    "vie.",
    "s\N{U+00e1}b.",
    "dom.",
  ],
  day_format_narrow => [
    "l",
    "m",
    "m",
    "j",
    "v",
    "s",
    "d",
  ],
  day_format_wide => [
    "lunes",
    "martes",
    "mi\N{U+00e9}rcoles",
    "jueves",
    "viernes",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  day_stand_alone_abbreviated => [
    "lun.",
    "mar.",
    "mi\N{U+00e9}.",
    "jue.",
    "vie.",
    "s\N{U+00e1}b.",
    "dom.",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "lunes",
    "martes",
    "mi\N{U+00e9}rcoles",
    "jueves",
    "viernes",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  era_abbreviated => [
    "a. C.",
    "d. C.",
  ],
  era_narrow => [
    "a. C.",
    "d. C.",
  ],
  era_wide => [
    "antes de Cristo",
    "despu\N{U+00e9}s de Cristo",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Spanish",
  month_format_abbreviated => [
    "ene.",
    "feb.",
    "mar.",
    "abr.",
    "may.",
    "jun.",
    "jul.",
    "ago.",
    "sep.",
    "oct.",
    "nov.",
    "dic.",
  ],
  month_format_narrow => [
    "E",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "enero",
    "febrero",
    "marzo",
    "abril",
    "mayo",
    "junio",
    "julio",
    "agosto",
    "septiembre",
    "octubre",
    "noviembre",
    "diciembre",
  ],
  month_stand_alone_abbreviated => [
    "ene.",
    "feb.",
    "mar.",
    "abr.",
    "may.",
    "jun.",
    "jul.",
    "ago.",
    "sep.",
    "oct.",
    "nov.",
    "dic.",
  ],
  month_stand_alone_narrow => [
    "E",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "enero",
    "febrero",
    "marzo",
    "abril",
    "mayo",
    "junio",
    "julio",
    "agosto",
    "septiembre",
    "octubre",
    "noviembre",
    "diciembre",
  ],
  name => "Spanish El Salvador",
  native_language => "espa\N{U+00f1}ol",
  native_name => "espa\N{U+00f1}ol El Salvador",
  native_script => undef,
  native_territory => "El Salvador",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre",
  ],
  script => undef,
  territory => "El Salvador",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> libdatetime-locale-perl_1.33.orig.tar.gz: DateTime-Locale-1.33/share/es-SV.pl <==
{
  am_pm_abbreviated => [
    "a.\N{U+00a0}m.",
    "p.\N{U+00a0}m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E d",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMM => "MMMM 'de' y G",
    GyMMMMEd => "E, d 'de' MMMM 'de' y G",
    GyMMMMd => "d 'de' MMMM 'de' y G",
    GyMMMd => "d 'de' MMM 'de' y G",
    GyMd => "d/M/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmsvvvv => "HH:mm:ss vvvv",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d 'de' MMMM",
    "MMMMW-count-one" => "'semana' W 'de' MMMM",
    "MMMMW-count-other" => "'semana' W 'de' MMMM",
    MMMMd => "d 'de' MMMM",
    MMMd => "d MMM",
    MMMdd => "dd-MMM",
    MMd => "d/M",
    MMdd => "d/M",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmsvvvv => "h:mm:ss a (vvvv)",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMM => "M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM 'de' y",
    yMMMMEd => "EEE, d 'de' MMMM 'de' y",
    yMMMMd => "d 'de' MMMM 'de' y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ 'de' y",
    yQQQQ => "QQQQ 'de' y",
    "yw-count-one" => "'semana' w 'de' Y",
    "yw-count-other" => "'semana' w 'de' Y",
  },
  code => "es-SV",
  date_format_full => "EEEE, d 'de' MMMM 'de' y",
  date_format_long => "d 'de' MMMM 'de' y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "lun",
    "mar",
    "mi\N{U+00e9}",
    "jue",
    "vie",
    "s\N{U+00e1}b",
    "dom",
  ],
  day_format_narrow => [
    "l",
    "m",
    "m",
    "j",
    "v",
    "s",
    "d",
  ],
  day_format_wide => [
    "lunes",
    "martes",
    "mi\N{U+00e9}rcoles",
    "jueves",
    "viernes",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  day_stand_alone_abbreviated => [
    "lun",
    "mar",
    "mi\N{U+00e9}",
    "jue",
    "vie",
    "s\N{U+00e1}b",
    "dom",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "lunes",
    "martes",
    "mi\N{U+00e9}rcoles",
    "jueves",
    "viernes",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  era_abbreviated => [
    "a. C.",
    "d. C.",
  ],
  era_narrow => [
    "a. C.",
    "d. C.",
  ],
  era_wide => [
    "antes de Cristo",
    "despu\N{U+00e9}s de Cristo",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Spanish",
  month_format_abbreviated => [
    "ene",
    "feb",
    "mar",
    "abr",
    "may",
    "jun",
    "jul",
    "ago",
    "sept",
    "oct",
    "nov",
    "dic",
  ],
  month_format_narrow => [
    "E",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "enero",
    "febrero",
    "marzo",
    "abril",
    "mayo",
    "junio",
    "julio",
    "agosto",
    "septiembre",
    "octubre",
    "noviembre",
    "diciembre",
  ],
  month_stand_alone_abbreviated => [
    "ene",
    "feb",
    "mar",
    "abr",
    "may",
    "jun",
    "jul",
    "ago",
    "sept",
    "oct",
    "nov",
    "dic",
  ],
  month_stand_alone_narrow => [
    "E",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "enero",
    "febrero",
    "marzo",
    "abril",
    "mayo",
    "junio",
    "julio",
    "agosto",
    "septiembre",
    "octubre",
    "noviembre",
    "diciembre",
  ],
  name => "Spanish El Salvador",
  native_language => "espa\N{U+00f1}ol",
  native_name => "espa\N{U+00f1}ol El Salvador",
  native_script => undef,
  native_territory => "El Salvador",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre",
  ],
  script => undef,
  territory => "El Salvador",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
